@@ -46,7 +46,13 @@ static USER_OBJECT_ makeSchemaReference(xmlSchemaPtr ref);
 USER_OBJECT_
 RS_XML(libxmlVersionRuntime)(void)
 {
-    return(mkString(*__xmlParserVersion()));
+    return(mkString(
+#if LIBXML_VERSION < 21200
+		*__xmlParserVersion()
+#else
+		xmlParserVersion
+#endif
+	));
 }
 
 
@@ -1063,7 +1069,7 @@ notifyError(const char *msg, va_list ap, Rboolean isError)
     memset(buf, '\0', BUFSIZE);
     vsnprintf(buf, BUFSIZE, msg, ap);
 
-    Rf_warning(buf);
+    Rf_warning("%s", buf);
 #endif
 }
 
